Documentation
¶
Index ¶
Constants ¶
const ( // DefaultDatabase is the default database for UDP traffic. DefaultDatabase = "udp" // DefaultBatchSize is the default UDP batch size. DefaultBatchSize = 1000 // DefaultBatchPending is the default number of pending UDP batches. DefaultBatchPending = 5 // DefaultBatchTimeout is the default UDP batch timeout. DefaultBatchTimeout = time.Second )
const (
UDPBufferSize = 65536
)
from https://en.wikipedia.org/wiki/User_Datagram_Protocol#Packet_structure
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Enabled bool `toml:"enabled"`
BindAddress string `toml:"bind-address"`
Database string `toml:"database"`
RetentionPolicy string `toml:"retention-policy"`
BatchSize int `toml:"batch-size"`
BatchPending int `toml:"batch-pending"`
BatchTimeout toml.Duration `toml:"batch-timeout"`
}
func (*Config) WithDefaults ¶
WithDefaults takes the given config and returns a new config with any required default values set.
type Service ¶
type Service struct {
PointsWriter interface {
WritePoints(p *cluster.WritePointsRequest) error
}
MetaStore interface {
CreateDatabaseIfNotExists(name string) (*meta.DatabaseInfo, error)
}
Logger *log.Logger
// contains filtered or unexported fields
}
Service represents here an UDP service that will listen for incoming packets formatted with the inline protocol
func NewService ¶
Click to show internal directories.
Click to hide internal directories.